@@ -153,7 +153,7 @@ def record_parameters(sysdata, execution_parameters, start_time):
     sysdata.write("\tnnls_add_penalty: {}\n".format(execution_parameters["nnls_add_penalty"]))
     sysdata.write("\tnnls_remove_penalty: {}\n".format(execution_parameters["nnls_remove_penalty"]))
     sysdata.write("\tinitial_remove_penalty: {}\n".format(execution_parameters["initial_remove_penalty"]))
-    sysdata.write("\trefit_denovo_signatures: {}\n".format(execution_parameters["refit_denovo_signatures"]))
+    sysdata.write("\texport_probabilities: {}\n".format(execution_parameters["export_probabilities"]))
     sysdata.write("\tcollapse_to_SBS96: {}\n".format(execution_parameters["collapse_to_SBS96"]))
     
     sysdata.write("\n-------Analysis Progress------- \n")
@@ -185,7 +185,6 @@ def sigProfilerExtractor(input_type,
                          nnls_add_penalty=0.05, 
                          nnls_remove_penalty=0.01,
                          initial_remove_penalty=0.05,
-                         refit_denovo_signatures=True,
                          collapse_to_SBS96=True,
                          clustering_distance="cosine",
                          export_probabilities=True,
@@ -393,7 +392,6 @@ def sigProfilerExtractor(input_type,
                         "nnls_add_penalty":nnls_add_penalty,
                         "nnls_remove_penalty":nnls_remove_penalty,
                         "initial_remove_penalty":initial_remove_penalty,
-                        "refit_denovo_signatures":refit_denovo_signatures,
                         "collapse_to_SBS96":collapse_to_SBS96,
                         "dist":clustering_distance,
                         "export_probabilities":export_probabilities,
@@ -554,6 +552,7 @@ def sigProfilerExtractor(input_type,
     elif input_type.lower()=="bedpe":
         ##################### For SV's bedpe input files #####################
         # create a directory to write the output matrices to
+        title = project
         mtypes = ["SV32"]
         sv_outputs = os.path.join(os.path.split(input_data)[0], "SV_Matrices")
 
@@ -573,6 +572,7 @@ def sigProfilerExtractor(input_type,
         # SV input processing, execution parameters
         #project needs to be something NOT a file
         genomes = scna.generateCNVMatrix(cnv_file_type, input_data, cnv_file_type, output)
+        genomes = genomes.set_index('MutationType')
         index = genomes.index.values
         colnames = genomes.columns
         allcolnames = colnames.copy()
@@ -852,7 +852,8 @@ def sigProfilerExtractor(input_type,
             sysdata.close()
             genome_build = "GRCh37"
 
-        decomp.spa_analyze(allgenomes, output, signatures=processAvg, genome_build=genome_build, cosmic_version=cosmic_version, exome=exome, verbose=False,decompose_fit_option= True,denovo_refit_option=True,cosmic_fit_option=False,devopts=devopts)
+        decomp.spa_analyze(allgenomes, output, signatures=processAvg, genome_build=genome_build, cosmic_version=cosmic_version, exome=exome, verbose=False,
+                           decompose_fit_option= True, denovo_refit_option=True, cosmic_fit_option=False, export_probabilities=export_probabilities, devopts=devopts)
 
         
     sysdata = open(out_put+"/JOB_METADATA.txt", "a")
@@ -862,4 +863,4 @@ def sigProfilerExtractor(input_type,
     sysdata.write("Analysis of mutational signatures completed successfully! \nTotal execution time: "+str(end_time-start_time).split(".")[0]+" \nResults can be found in: "+" "+out_put+ " " +" folder")
     sysdata.close()
 
-    print("\n\n \nYour Job Is Successfully Completed! Thank You For Using SigProfiler Extractor.\n ")
+    print("\n\n \nYour Job Is Successfully Completed! Thank You For Using SigProfilerExtractor.\n ")
